@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from collections import defaultdict
 from textwrap import dedent
-from typing import List, NamedTuple, Optional
+from typing import TYPE_CHECKING, List, NamedTuple, Optional
 
 import attrs
 from graphql import language as gql_lang
@@ -12,17 +12,22 @@ from qtgql.codegen.py.compiler.template import (
     ConfigContext,
     config_template,
 )
-from qtgql.codegen.py.objecttype import GqlFieldDefinition, GqlTypeDefinition
+from qtgql.codegen.py.objecttype import QtGqlFieldDefinition, QtGqlObjectTypeDefinition
 from qtgql.codegen.utils import AntiForwardRef
 
+if TYPE_CHECKING:
+    from qtgql.codegen.py.objecttype import QtGqlVariableDefinition
+
 
 def get_field_from_field_node(
-    selection: gql_lang.FieldNode, field_type: GqlTypeDefinition
+    selection: gql_lang.FieldNode,
+    field_type: QtGqlObjectTypeDefinition,
 ) -> QtGqlQueriedField:
     field_node = is_field_node(selection)
     assert field_node
     return QtGqlQueriedField.from_field(
-        field_type.fields_dict[field_node.name.value], selection_set=field_node.selection_set
+        field_type.fields_dict[field_node.name.value],
+        selection_set=field_node.selection_set,
     )
 
 
@@ -37,20 +42,22 @@ def inject_id_selection(selection_set: gql_lang.SelectionSetNode) -> None:
 
 def has_id_field(selection_set: gql_lang.SelectionSetNode) -> bool:
     for field in selection_set.selections:
-        assert isinstance(field, gql_lang.FieldNode)
+        assert isinstance(field, gql_lang.FieldNode), f"{field} is not a field"
         if field.name.value == "id":
             return True
     return False
 
 
 @attrs.define
-class QtGqlQueriedField(GqlFieldDefinition):
+class QtGqlQueriedField(QtGqlFieldDefinition):
     selections: List[QtGqlQueriedField] = attrs.Factory(list)
     choices: dict[str, List[QtGqlQueriedField]] = attrs.Factory(lambda: defaultdict(list))
 
     @classmethod
     def from_field(
-        cls, f: GqlFieldDefinition, selection_set: Optional[gql_lang.SelectionSetNode]
+        cls,
+        f: QtGqlFieldDefinition,
+        selection_set: Optional[gql_lang.SelectionSetNode],
     ) -> QtGqlQueriedField:
         ret = cls(**attrs.asdict(f, recurse=False))
         if not hasattr(selection_set, "selections"):
@@ -70,7 +77,7 @@ class QtGqlQueriedField(GqlFieldDefinition):
                 concrete = next(t for t in tp.of_type if t.type.name == type_name)
                 assert issubclass(concrete.type, AntiForwardRef)
                 concrete = concrete.type.resolve()
-                assert isinstance(concrete, GqlTypeDefinition)
+                assert isinstance(concrete, QtGqlObjectTypeDefinition)
                 if not has_id_field(inline_frag.selection_set) and concrete.has_id_field:
                     inject_id_selection(inline_frag.selection_set)
 
@@ -95,16 +102,17 @@ class QtGqlQueriedField(GqlFieldDefinition):
         return dedent(
             config_template(
                 context=ConfigContext(self),
-            )
+            ),
         )
 
 
-class QtGqlQueryHandlerDefinition(NamedTuple):
+class QtGqlOperationDefinition(NamedTuple):
     query: str
     name: str
     field: QtGqlQueriedField
     directives: list[str] = []
     fragments: list[str] = []
+    variables: list[QtGqlVariableDefinition] = []
 
     @property
     def operation_config(self) -> str:
